/**
 * 用户逻辑
 */

import { DOCUMENTTYPE, MEMBERLEVEL, MEMBERTYPE, NATION, PROFCATEGORY, SEX, UNITINFOTYPE } from "../../config/enum";
import { ERRORCODEENUM, ERRORENUM } from "../../config/errorEnum";
import { addOneData } from "../../data/add";
import { TABLEENUM } from "../../data/models/model";
import { findOnce } from "../../data/select";
import { updateOneData } from "../../data/update";
import { generateToken, generateUserId, successResult } from "../../tools/system";
import { BizError } from "../../util/bizError";
import { eccEnumValue } from "../../util/verificationEnum";



/**
 * 登陆
 * @param param0 
 * @returns 
 */
export async function login({loginId, pwd }) {
    let userInfo = await findOnce(TABLEENUM.用户表, {loginId});
    
    if (!userInfo || !userInfo.userId) throw new BizError(ERRORENUM.账号或密码错误);
    if (userInfo.pwd != pwd ) throw new BizError(ERRORENUM.账号或密码错误);

    let token = generateToken(userInfo.userId);
    await updateOneData(TABLEENUM.用户表, {userId:userInfo.userId}, {token, tokenMs:new Date().valueOf()});

    return {
        userInfo:{
            isAdmin:userInfo.isAdmin == 1,
            name:userInfo.name,
            userId:userInfo.userId,
            token:token
        }
    }
}


/**
 * 退出登陆
 * @param userId 
 * @returns 
 */
export async function logout({userId}) {
    let token = generateToken(userId);
    await updateOneData(TABLEENUM.用户表, {userId:userId}, {token});

    return successResult();
}



